@@ -1,4 +1,4 @@
-/* Copyright 2016-2020 Dimitrij Mijoski
+/* Copyright 2016-2021 Dimitrij Mijoski
  *
  * This file is part of Nuspell.
  *
@@ -33,15 +33,11 @@ namespace nuspell {
 /**
  * @brief Library main namespace with version number attached
  *
- * @internal
- * Everything that is public API gets here, and even symbols that should be
- * private at API but are called at ABI level end up here. For example, our
- * public class Dictionary has implicit destructor which gets inlined in client
- * code. Thus, the client code directly calls the destructors of all the private
- * data members of our class Dictionary.
+ * This inline namespace is used for ABI versioning. It is the same as the major
+ * verison. Look up on the Internet to see what is it for (ABI versioning
+ * mostly). Client code should never mention this inline namespace.
  */
-inline namespace v4 {
-}
+inline namespace v5 {
 
 auto Encoding::normalize_name() -> void
 {
@@ -379,12 +375,12 @@ class Aff_Line_IO_Manip {
 		return in;
 	}
 
-	auto& parse(istream& in, std::wstring& wstr)
+	auto& parse(istream& in, std::string& str)
 	{
 		in >> str_buf;
 		if (in.fail()) // str_buf is unmodified on fail
 			return in;
-		auto ok = cvt.to_wide(str_buf, wstr);
+		auto ok = cvt.to_utf8(str_buf, str);
 		if (!ok)
 			in.setstate(in.failbit);
 		return in;
@@ -451,8 +447,7 @@ class Aff_Line_IO_Manip {
 		return in;
 	}
 
-	auto& parse_word_slash_flags(istream& in, wstring& word,
-	                             Flag_Set& flags)
+	auto& parse_word_slash_flags(istream& in, string& word, Flag_Set& flags)
 	{
 		using Err = Parsing_Error_Code;
 		in >> str_buf;
@@ -471,7 +466,7 @@ class Aff_Line_IO_Manip {
 				err = Err::NO_FLAGS_AFTER_SLASH_WARNING;
 			flags = flag_buffer;
 		}
-		auto ok = cvt.to_wide(str_buf, word);
+		auto ok = cvt.to_utf8(str_buf, word);
 		if (!ok)
 			in.setstate(in.failbit);
 		if (static_cast<int>(err) > 0)
@@ -479,7 +474,7 @@ class Aff_Line_IO_Manip {
 		return in;
 	}
 
-	auto parse_word_slash_single_flag(istream& in, wstring& word,
+	auto parse_word_slash_single_flag(istream& in, string& word,
 	                                  char16_t& flag) -> istream&
 	{
 		in >> str_buf;
@@ -496,7 +491,7 @@ class Aff_Line_IO_Manip {
 			if (!flag_buffer.empty())
 				flag = flag_buffer[0];
 		}
-		auto ok = cvt.to_wide(str_buf, word);
+		auto ok = cvt.to_utf8(str_buf, word);
 		if (!ok)
 			in.setstate(in.failbit);
 		if (static_cast<int>(err) > 0)
@@ -541,19 +536,19 @@ auto& operator>>(istream& in, Ref_Wrapper_1<T> x)
 	return x.manip.parse(in, x.data);
 }
 
-auto& operator>>(istream& in, Ref_Wrapper_1<pair<wstring, wstring>> x)
+auto& operator>>(istream& in, Ref_Wrapper_1<pair<string, string>> x)
 {
 	return in >> x.manip(x.data.first) >> x.manip(x.data.second);
 }
 
-auto& operator>>(istream& in, Ref_Wrapper_1<Condition<wchar_t>> x)
+auto& operator>>(istream& in, Ref_Wrapper_1<Condition> x)
 {
-	auto wstr = wstring();
-	in >> x.manip(wstr);
+	auto str = string();
+	in >> x.manip(str);
 	if (in.fail())
 		return in;
 	try {
-		x.data = std::move(wstr);
+		x.data = std::move(str);
 	}
 	catch (const Condition_Exception& ex) {
 		x.manip.err = Parsing_Error_Code::AFX_CONDITION_INVALID_FORMAT;
@@ -567,27 +562,27 @@ auto& operator>>(istream& in, Ref_Wrapper_1_Cpd_Rule x)
 	return x.manip.parse_compound_rule(in, x.data.rule);
 }
 
-auto& operator>>(istream& in, Ref_Wrapper_2<wstring, Flag_Set> x)
+auto& operator>>(istream& in, Ref_Wrapper_2<string, Flag_Set> x)
 {
 	return x.manip.parse_word_slash_flags(in, x.data1, x.data2);
 }
 
-auto& operator>>(istream& in, Ref_Wrapper_2<wstring, char16_t> x)
+auto& operator>>(istream& in, Ref_Wrapper_2<string, char16_t> x)
 {
 	return x.manip.parse_word_slash_single_flag(in, x.data1, x.data2);
 }
 
-auto& operator>>(istream& in, Ref_Wrapper_1<Compound_Pattern<wchar_t>> x)
+auto& operator>>(istream& in, Ref_Wrapper_1<Compound_Pattern> x)
 {
 	auto [manip, p] = x;
-	auto first_word_end = wstring();
-	auto second_word_begin = wstring();
+	auto first_word_end = string();
+	auto second_word_begin = string();
 	p.match_first_only_unaffixed_or_zero_affixed = false;
 	in >> manip(first_word_end, p.first_word_flag);
 	in >> manip(second_word_begin, p.second_word_flag);
 	if (in.fail())
 		return in;
-	if (first_word_end == L"0") {
+	if (first_word_end == "0") {
 		first_word_end.clear();
 		p.match_first_only_unaffixed_or_zero_affixed = true;
 	}
@@ -671,10 +666,10 @@ auto parse_affix(istream& in, Aff_Line_IO_Manip& p, string& command,
 		elem.flag = f;
 		elem.cross_product = dat->second.first;
 		in >> p(elem.stripping);
-		if (elem.stripping == L"0")
+		if (elem.stripping == "0")
 			elem.stripping.clear();
 		in >> p(elem.appending, elem.cont_flags);
-		if (elem.appending == L"0")
+		if (elem.appending == "0")
 			elem.appending.clear();
 		if (in.fail())
 			return;
@@ -682,7 +677,7 @@ auto parse_affix(istream& in, Aff_Line_IO_Manip& p, string& command,
 		in.exceptions(in.goodbit);
 		in >> p(elem.condition); // optional
 		if (in.fail() && in.eof() && !in.bad()) {
-			elem.condition = L".";
+			elem.condition = ".";
 			reset_failbit_istream(in);
 		}
 		in.exceptions(old_mask);
@@ -699,28 +694,28 @@ auto parse_affix(istream& in, Aff_Line_IO_Manip& p, string& command,
 
 auto Aff_Data::parse_aff(istream& in) -> bool
 {
-	auto prefixes = vector<Prefix<wchar_t>>();
-	auto suffixes = vector<Suffix<wchar_t>>();
-	auto break_patterns = vector<wstring>();
+	auto prefixes = vector<Prefix>();
+	auto suffixes = vector<Suffix>();
+	auto break_patterns = vector<string>();
 	auto break_exists = false;
-	auto input_conversion = vector<pair<wstring, wstring>>();
-	auto output_conversion = vector<pair<wstring, wstring>>();
+	auto input_conversion = vector<pair<string, string>>();
+	auto output_conversion = vector<pair<string, string>>();
 	// auto morphological_aliases = vector<vector<string>>();
 	auto rules = vector<u16string>();
-	auto replacements = vector<pair<wstring, wstring>>();
-	auto map_related_chars = vector<wstring>();
-	auto phonetic_replacements = vector<pair<wstring, wstring>>();
+	auto replacements = vector<pair<string, string>>();
+	auto map_related_chars = vector<string>();
+	auto phonetic_replacements = vector<pair<string, string>>();
 
 	max_compound_suggestions = 3;
 	max_ngram_suggestions = 4;
 	max_diff_factor = 5;
 	flag_type = Flag_Type::SINGLE_CHAR;
 
-	unordered_map<string, wstring*> command_wstrings = {
+	unordered_map<string, string*> command_strings = {
 	    {"IGNORE", &ignored_chars},
 
 	    {"KEY", &keyboard_closeness},
-	    {"TRY", &this->try_chars}};
+	    {"TRY", &try_chars}};
 
 	unordered_map<string, bool*> command_bools = {
 	    {"COMPLEXPREFIXES", &complex_prefixes},
@@ -749,11 +744,11 @@ auto Aff_Data::parse_aff(istream& in) -> bool
 	    {"COMPOUNDMIN", &compound_min_length},
 	    {"COMPOUNDWORDMAX", &compound_max_word_count}};
 
-	unordered_map<string, vector<pair<wstring, wstring>>*>
-	    command_vec_pair = {{"REP", &replacements},
-	                        {"PHONE", &phonetic_replacements},
-	                        {"ICONV", &input_conversion},
-	                        {"OCONV", &output_conversion}};
+	unordered_map<string, vector<pair<string, string>>*> command_vec_pair =
+	    {{"REP", &replacements},
+	     {"PHONE", &phonetic_replacements},
+	     {"ICONV", &input_conversion},
+	     {"OCONV", &output_conversion}};
 
 	unordered_map<string, char16_t*> command_flag = {
 	    {"NOSUGGEST", &nosuggest_flag},
@@ -809,8 +804,8 @@ auto Aff_Data::parse_aff(istream& in) -> bool
 		else if (command == "PFX") {
 			parse_affix(ss, p, command, prefixes, cmd_affix);
 		}
-		else if (command_wstrings.count(command)) {
-			auto& str = *command_wstrings[command];
+		else if (command_strings.count(command)) {
+			auto& str = *command_strings[command];
 			if (str.empty())
 				ss >> p(str);
 			else
@@ -905,11 +900,11 @@ auto Aff_Data::parse_aff(istream& in) -> bool
 	}
 	// default BREAK definition
 	if (!break_exists) {
-		break_patterns = {L"-", L"^-", L"-$"};
+		break_patterns = {"-", "^-", "-$"};
 	}
 	for (auto& r : replacements) {
 		auto& s = r.second;
-		replace_char(s, L'_', L' ');
+		replace_ascii_char(s, '_', ' ');
 	}
 
 	// now fill data structures from temporary data
@@ -919,7 +914,7 @@ auto Aff_Data::parse_aff(istream& in) -> bool
 	input_substr_replacer = std::move(input_conversion);
 	output_substr_replacer = std::move(output_conversion);
 	this->replacements = std::move(replacements);
-	phonetic_table = std::move(phonetic_replacements);
+	// phonetic_table = std::move(phonetic_replacements);
 	for (auto& x : prefixes) {
 		erase_chars(x.appending, ignored_chars);
 	}
@@ -972,7 +967,7 @@ auto Aff_Data::parse_dic(istream& in) -> bool
 	string word;
 	string flags_str;
 	u16string flags;
-	wstring wide_word;
+	string u8word;
 	auto enc_conv = Encoding_Converter(encoding.value_or_default());
 
 	// locale must be without thousands separator.
@@ -1034,12 +1029,12 @@ auto Aff_Data::parse_dic(istream& in) -> bool
 		}
 		if (word.empty())
 			continue;
-		auto ok = enc_conv.to_wide(word, wide_word);
+		auto ok = enc_conv.to_utf8(word, u8word);
 		if (!ok)
 			continue;
-		erase_chars(wide_word, ignored_chars);
-		auto casing = classify_casing(wide_word);
-		auto inserted = words.emplace(wide_word, flags);
+		erase_chars(u8word, ignored_chars);
+		auto casing = classify_casing(u8word);
+		auto inserted = words.emplace(u8word, flags);
 		switch (casing) {
 		case Casing::ALL_CAPITAL:
 			if (flags.empty())
@@ -1054,9 +1049,9 @@ auto Aff_Data::parse_dic(istream& in) -> bool
 			// entries.
 			if (inserted->second.contains(forbiddenword_flag))
 				break;
-			auto title_word = to_title(wide_word, icu_locale);
+			to_title(u8word, icu_locale, u8word);
 			flags += HIDDEN_HOMONYM_FLAG;
-			words.emplace(title_word, flags);
+			words.emplace(u8word, flags);
 			break;
 		}
 		default:
@@ -1065,4 +1060,5 @@ auto Aff_Data::parse_dic(istream& in) -> bool
 	}
 	return in.eof(); // success if we reached eof
 }
+} // namespace v5
 } // namespace nuspell
