@@ -1,4 +1,4 @@
-/* Copyright 2016-2020 Dimitrij Mijoski, Sander van Geloven
+/* Copyright 2016-2021 Dimitrij Mijoski, Sander van Geloven
  *
  * This file is part of Nuspell.
  *
@@ -27,7 +27,7 @@
 #include <unicode/ucnv.h>
 
 #if defined(__MINGW32__) || defined(__unix__) || defined(__unix) ||            \
-    (defined(__APPLE__) && defined(__MACH__))
+    (defined(__APPLE__) && defined(__MACH__)) || defined(__HAIKU__)
 #include <getopt.h>
 #include <unistd.h>
 #endif
@@ -250,7 +250,7 @@ auto print_version() -> void
 {
 	cout << PACKAGE_STRING
 	    "\n"
-	    "Copyright (C) 2016-2020 Dimitrij Mijoski and Sander van Geloven\n"
+	    "Copyright (C) 2016-2021 Dimitrij Mijoski and Sander van Geloven\n"
 	    "License LGPLv3+: GNU LGPL version 3 or later "
 	    "<http://gnu.org/licenses/lgpl.html>.\n"
 	    "This is free software: you are free to change and "
